@@ -1,6 +1,35 @@
 from typing import Optional, List, Union, Any, Dict
 
 
+class App:
+    id: Optional[str]
+    name: Optional[str]
+    is_distributed: Optional[bool]
+    is_directory_approved: Optional[bool]
+    is_workflow_app: Optional[bool]
+    scopes: Optional[List[str]]
+    unknown_fields: Dict[str, Any]
+
+    def __init__(
+        self,
+        *,
+        id: Optional[str] = None,
+        name: Optional[str] = None,
+        is_distributed: Optional[bool] = None,
+        is_directory_approved: Optional[bool] = None,
+        is_workflow_app: Optional[bool] = None,
+        scopes: Optional[List[str]] = None,
+        **kwargs,
+    ) -> None:
+        self.id = id
+        self.name = name
+        self.is_distributed = is_distributed
+        self.is_directory_approved = is_directory_approved
+        self.is_workflow_app = is_workflow_app
+        self.scopes = scopes
+        self.unknown_fields = kwargs
+
+
 class User:
     id: Optional[str]
     name: Optional[str]
@@ -68,6 +97,7 @@ class Context:
     ua: Optional[str]
     ip_address: Optional[str]
     session_id: Optional[str]
+    app: Optional[App]
     unknown_fields: Dict[str, Any]
 
     def __init__(
@@ -77,12 +107,14 @@ class Context:
         ua: Optional[str] = None,
         ip_address: Optional[str] = None,
         session_id: Optional[str] = None,
+        app: Optional[App] = None,
         **kwargs,
     ) -> None:
         self.location = Location(**location) if isinstance(location, dict) else location
         self.ua = ua
         self.ip_address = ip_address
         self.session_id = session_id
+        self.app = app
         self.unknown_fields = kwargs
 
 
@@ -118,6 +150,19 @@ class ConversationPref:
         self.unknown_fields = kwargs
 
 
+class FeatureEnablement:
+    enabled: Optional[bool]
+
+    def __init__(
+        self,
+        *,
+        enabled: Optional[bool] = None,
+        **kwargs,
+    ) -> None:
+        self.enabled = enabled
+        self.unknown_fields = kwargs
+
+
 class Details:
     name: Optional[str]
     new_value: Optional[Union[str, List[str], Dict[str, Any]]]
@@ -142,6 +187,7 @@ class Details:
     previous_scopes: Optional[List[str]]
     granular_bot_token: Optional[bool]
     scopes: Optional[List[str]]
+    scopes_bot: Optional[List[str]]
     resolution: Optional[str]
     app_previously_resolved: Optional[bool]
     admin_app_id: Optional[str]
@@ -182,6 +228,12 @@ class Details:
     session_search_start: Optional[int]
     deprecation_search_end: Optional[int]
     is_error: Optional[bool]
+    creator: Optional[str]
+    team: Optional[str]
+    app_id: Optional[str]
+    enable_at_here: Optional[FeatureEnablement]
+    enable_at_channel: Optional[FeatureEnablement]
+    can_huddle: Optional[FeatureEnablement]
 
     def __init__(
         self,
@@ -209,6 +261,7 @@ class Details:
         previous_scopes: Optional[List[str]] = None,
         granular_bot_token: Optional[bool] = None,
         scopes: Optional[List[str]] = None,
+        scopes_bot: Optional[List[str]] = None,
         resolution: Optional[str] = None,
         app_previously_resolved: Optional[bool] = None,
         admin_app_id: Optional[str] = None,
@@ -248,6 +301,12 @@ class Details:
         session_search_start: Optional[int] = None,
         deprecation_search_end: Optional[int] = None,
         is_error: Optional[bool] = None,
+        creator: Optional[str] = None,
+        team: Optional[str] = None,
+        app_id: Optional[str] = None,
+        enable_at_here: Optional[FeatureEnablement] = None,
+        enable_at_channel: Optional[FeatureEnablement] = None,
+        can_huddle: Optional[FeatureEnablement] = None,
         **kwargs,
     ) -> None:
         self.name = name
@@ -259,8 +318,12 @@ class Details:
         self.non_sso_only = non_sso_only
         self.type = type
         self.is_workflow = is_workflow
-        self.inviter = inviter if isinstance(inviter, User) else User(**inviter)
-        self.kicker = kicker if isinstance(kicker, User) else User(**kicker)
+        self.inviter = (
+            inviter if inviter is None or isinstance(inviter, User) else User(**inviter)
+        )
+        self.kicker = (
+            kicker if kicker is None or isinstance(kicker, User) else User(**kicker)
+        )
         self.shared_to = shared_to
         self.reason = reason
         self.origin_team = origin_team
@@ -273,6 +336,7 @@ class Details:
         self.previous_scopes = previous_scopes
         self.granular_bot_token = granular_bot_token
         self.scopes = scopes
+        self.scopes_bot = scopes_bot
         self.resolution = resolution
         self.app_previously_resolved = app_previously_resolved
         self.admin_app_id = admin_app_id
@@ -306,22 +370,24 @@ class Details:
         self.is_token_rotation_enabled_app = is_token_rotation_enabled_app
         self.old_retention_policy = (
             old_retention_policy
-            if isinstance(old_retention_policy, RetentionPolicy)
+            if old_retention_policy is None
+            or isinstance(old_retention_policy, RetentionPolicy)
             else RetentionPolicy(**old_retention_policy)
         )
         self.new_retention_policy = (
             new_retention_policy
-            if isinstance(new_retention_policy, RetentionPolicy)
+            if new_retention_policy is None
+            or isinstance(new_retention_policy, RetentionPolicy)
             else RetentionPolicy(**new_retention_policy)
         )
         self.who_can_post = (
             who_can_post
-            if isinstance(who_can_post, ConversationPref)
+            if who_can_post is None or isinstance(who_can_post, ConversationPref)
             else ConversationPref(**who_can_post)
         )
         self.can_thread = (
             can_thread
-            if isinstance(can_thread, ConversationPref)
+            if can_thread is None or isinstance(can_thread, ConversationPref)
             else ConversationPref(**can_thread)
         )
         self.is_external_limited = is_external_limited
@@ -329,35 +395,25 @@ class Details:
         self.session_search_start = session_search_start
         self.deprecation_search_end = deprecation_search_end
         self.is_error = is_error
-
-
-class App:
-    id: Optional[str]
-    name: Optional[str]
-    is_distributed: Optional[bool]
-    is_directory_approved: Optional[bool]
-    is_workflow_app: Optional[bool]
-    scopes: Optional[List[str]]
-    unknown_fields: Dict[str, Any]
-
-    def __init__(
-        self,
-        *,
-        id: Optional[str] = None,
-        name: Optional[str] = None,
-        is_distributed: Optional[bool] = None,
-        is_directory_approved: Optional[bool] = None,
-        is_workflow_app: Optional[bool] = None,
-        scopes: Optional[List[str]] = None,
-        **kwargs,
-    ) -> None:
-        self.id = id
-        self.name = name
-        self.is_distributed = is_distributed
-        self.is_directory_approved = is_directory_approved
-        self.is_workflow_app = is_workflow_app
-        self.scopes = scopes
-        self.unknown_fields = kwargs
+        self.creator = creator
+        self.team = team
+        self.app_id = app_id
+        self.enable_at_here = (
+            enable_at_here
+            if enable_at_here is None or isinstance(enable_at_here, FeatureEnablement)
+            else FeatureEnablement(**enable_at_here)
+        )
+        self.enable_at_channel = (
+            enable_at_channel
+            if enable_at_channel is None
+            or isinstance(enable_at_channel, FeatureEnablement)
+            else FeatureEnablement(**enable_at_channel)
+        )
+        self.can_huddle = (
+            can_huddle
+            if can_huddle is None or isinstance(can_huddle, FeatureEnablement)
+            else FeatureEnablement(**can_huddle)
+        )
 
 
 class Channel:
